What's new in the latest versions
=================================

The new version of NoLOAD v1.2.4 is available!
The release is from 13th of December 2021.

.. toctree::
   :maxdepth: 2

   new_features/v1.2.4


Information about the latest versions
-------------------------------------

.. toctree::
   :maxdepth: 1

   new_features/v1.2.3
   new_features/v1.2.2
   new_features/v1.2.1
   new_features/v1.2.0
   new_features/v1.1.0
   new_features/v1.0.3
